<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\Contactcenterinsights;

class GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadataIngestConversationsStats extends \Google\Model
{
  /**
   * @var int
   */
  public $duplicatesSkippedCount;
  /**
   * @var int
   */
  public $failedIngestCount;
  /**
   * @var int
   */
  public $processedObjectCount;
  /**
   * @var int
   */
  public $successfulIngestCount;

  /**
   * @param int
   */
  public function setDuplicatesSkippedCount($duplicatesSkippedCount)
  {
    $this->duplicatesSkippedCount = $duplicatesSkippedCount;
  }
  /**
   * @return int
   */
  public function getDuplicatesSkippedCount()
  {
    return $this->duplicatesSkippedCount;
  }
  /**
   * @param int
   */
  public function setFailedIngestCount($failedIngestCount)
  {
    $this->failedIngestCount = $failedIngestCount;
  }
  /**
   * @return int
   */
  public function getFailedIngestCount()
  {
    return $this->failedIngestCount;
  }
  /**
   * @param int
   */
  public function setProcessedObjectCount($processedObjectCount)
  {
    $this->processedObjectCount = $processedObjectCount;
  }
  /**
   * @return int
   */
  public function getProcessedObjectCount()
  {
    return $this->processedObjectCount;
  }
  /**
   * @param int
   */
  public function setSuccessfulIngestCount($successfulIngestCount)
  {
    $this->successfulIngestCount = $successfulIngestCount;
  }
  /**
   * @return int
   */
  public function getSuccessfulIngestCount()
  {
    return $this->successfulIngestCount;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadataIngestConversationsStats::class, 'Google_Service_Contactcenterinsights_GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadataIngestConversationsStats');
